.. _reference:

Reference
=========

This is the class and function reference of pyrwt. Please refer to
the :ref:`tutorial <tutorial>` for further details, as the class and
function raw specifications may not be enough to give full guidelines on their
uses.

.. autofunction:: rwt.dwt


.. autofunction:: rwt.idwt


.. autofunction:: rwt.rdwt


.. autofunction:: rwt.irdwt


.. autofunction:: rwt.dwtaxis


.. autofunction:: rwt.idwtaxis


.. automodule:: rwt.utilities


.. autofunction:: rwt.utilities.hardThreshold


.. autofunction:: rwt.utilities.softThreshold


.. autofunction:: rwt.utilities.makeSignal


